@@ -20,84 +20,38 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-eventbridge-stepfunctions`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.eventbridgestepfunctions`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS Events rule and an AWS Step Functions State Machine
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
-
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps, Duration } from 'aws-cdk-lib';
-import { EventbridgeToStepfunctions, EventbridgeToStepfunctionsProps } from '@aws-solutions-constructs/aws-eventbridge-stepfunctions';
-import * as stepfunctions from 'aws-cdk-lib/aws-stepfunctions';
-import * as events from 'aws-cdk-lib/aws-events';
+```javascript
+const { EventbridgeToStepfunctions, EventbridgeToStepfunctionsProps } from '@aws-solutions-constructs/aws-eventbridge-stepfunctions';
 
 const startState = new stepfunctions.Pass(this, 'StartState');
 
-const constructProps: EventbridgeToStepfunctionsProps = {
-  stateMachineProps: {
-    definition: startState
-  },
-  eventRuleProps: {
-    schedule: events.Schedule.rate(Duration.minutes(5))
-  }
+const props: EventbridgeToStepfunctionsProps = {
+    stateMachineProps: {
+      definition: startState
+    },
+    eventRuleProps: {
+      schedule: events.Schedule.rate(Duration.minutes(5))
+    }
 };
 
-new EventbridgeToStepfunctions(this, 'test-eventbridge-stepfunctions-stack', constructProps);
+new EventbridgeToStepfunctions(stack, 'test-eventbridge-stepfunctions-stack', props);
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_eventbridge_stepfunctions import EventbridgeToStepfunctions, EventbridgeToStepfunctionsProps
-from aws_cdk import (
-    aws_stepfunctions as stepfunctions,
-    aws_events as events,
-    Duration,
-    Stack
-)
-from constructs import Construct
-
-startState = stepfunctions.Pass(self, 'StartState')
-
-EventbridgeToStepfunctions(self, 'test-eventbridge-stepfunctions-stack',
-                            state_machine_props=stepfunctions.StateMachineProps(
-                                definition=startState
-                            ),
-                            event_rule_props=events.RuleProps(
-                                schedule=events.Schedule.rate(
-                                    Duration.minutes(5))
-                            ))
+```text
+new EventbridgeToStepfunctions(scope: Construct, id: string, props: EventbridgeToStepfunctionsProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.Duration;
-import software.amazon.awscdk.services.events.*;
-import software.amazon.awscdk.services.stepfunctions.*;
-import software.amazon.awsconstructs.services.eventbridgestepfunctions.*;
-
-final Pass startState = new Pass(this, "StartState");
-
-new EventbridgeToStepfunctions(this,
-        "test-eventbridge-stepfunctions-stack",
-        new EventbridgeToStepfunctionsProps.Builder()
-                .stateMachineProps(new StateMachineProps.Builder()
-                        .definition(startState)
-                        .build())
-                .eventRuleProps(new RuleProps.Builder()
-                        .schedule(Schedule.rate(Duration.minutes(5)))
-                        .build())
-                .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`EventbridgeToStepfunctionsProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -140,7 +94,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -152,33 +106,31 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_events
 import aws_cdk.aws_logs
 import aws_cdk.aws_stepfunctions
-import aws_cdk.core
+import constructs
 
 
 class EventbridgeToStepfunctions(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-eventbridge-stepfunctions.EventbridgeToStepfunctions",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -193,22 +145,6 @@ class EventbridgeToStepfunctions(
         :access: public
         :summary: Constructs a new instance of the EventbridgeToStepfunctions class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToStepfunctionsProps(
             event_rule_props=event_rule_props,
             state_machine_props=state_machine_props,
@@ -220,29 +156,29 @@ class EventbridgeToStepfunctions(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
         return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -264,12 +200,12 @@ class EventbridgeToStepfunctionsProps:
     def __init__(
         self,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -289,24 +225,6 @@ class EventbridgeToStepfunctionsProps:
             event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
-        if __debug__:
-            def stub(
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
-            check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
-            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
-            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
-            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
-            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
             "state_machine_props": state_machine_props,
